@@ -18,7 +18,6 @@ from urllib import parse
 
 import fixtures
 import sqlalchemy
-from sqlalchemy.dialects import mysql
 from sqlalchemy import Boolean, Index, Integer, DateTime, String
 from sqlalchemy import CheckConstraint
 from sqlalchemy import MetaData, Table, Column
@@ -93,7 +92,7 @@ class FakeTable(Base):
 class FakeTableJoinedInh(FakeTable):
     __tablename__ = 'fake_table_inh'
 
-    id = Column(String(50), ForeignKey('fake_table.user_id'))
+    id = Column(String(50), ForeignKey('fake_table.user_id'), primary_key=True)
 
 
 class FakeTableSingleInh(FakeTable):
@@ -476,14 +475,14 @@ class TestPaginateQuery(test_base.BaseTestCase):
             mock.call('desc_null_3'),
             mock.call(self.model.project_id),
         ])
-        self.query.order_by.assert_has_calls = [
+        self.query.order_by.assert_has_calls([
             mock.call('asc_null_2'),
             mock.call('asc_1'),
             mock.call('desc_null_2'),
             mock.call('desc_1'),
             mock.call('desc_null_4'),
             mock.call('desc_4'),
-        ]
+        ])
         mock_or.assert_has_calls([
             mock.call(mock.ANY, 'asc_null_filter_2'),
             mock.call(mock.ANY, 'desc_null_filter_3'),
@@ -699,7 +698,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
                            Column('updated_at', DateTime))
 
         test_table.create(engine)
-        with engine.connect() as conn:
+        with engine.connect() as conn, conn.begin():
             conn.execute(test_table.insert(), values)
         return test_table, values
 
@@ -720,7 +719,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
             uniq_values.add(uniq_value)
             expected_ids.append(value['id'])
 
-        with self.engine.connect() as conn:
+        with self.engine.connect() as conn, conn.begin():
             real_ids = [
                 row[0] for row in
                 conn.execute(select(test_table.c.id)).fetchall()
@@ -762,7 +761,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
 
         base_select = table.select()
 
-        with self.engine.connect() as conn:
+        with self.engine.connect() as conn, conn.begin():
             rows_select = base_select.where(table.c.deleted != table.c.id)
             row_ids = [
                 row.id for row in conn.execute(rows_select).fetchall()
@@ -782,129 +781,6 @@ class TestMigrationUtils(db_test_base._DbTestCase):
         for value in soft_deleted_values:
             self.assertIn(value['id'], deleted_rows_ids)
 
-    def test_change_deleted_column_type_does_not_drop_index(self):
-        table_name = 'abc'
-
-        indexes = {
-            'idx_a_deleted': ['a', 'deleted'],
-            'idx_b_deleted': ['b', 'deleted'],
-            'idx_a': ['a']
-        }
-
-        index_instances = [Index(name, *columns)
-                           for name, columns in indexes.items()]
-
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('a', String(255)),
-                      Column('b', String(255)),
-                      Column('deleted', Boolean),
-                      *index_instances)
-        table.create(self.engine)
-        utils.change_deleted_column_type_to_id_type(self.engine, table_name)
-        utils.change_deleted_column_type_to_boolean(self.engine, table_name)
-
-        insp = sqlalchemy.inspect(self.engine)
-        real_indexes = insp.get_indexes(table_name)
-        self.assertEqual(3, len(real_indexes))
-        for index in real_indexes:
-            name = index['name']
-            self.assertIn(name, indexes)
-            self.assertEqual(set(indexes[name]),
-                             set(index['column_names']))
-
-    def test_change_deleted_column_type_to_id_type_integer(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('deleted', Boolean))
-        table.create(self.engine)
-        utils.change_deleted_column_type_to_id_type(self.engine, table_name)
-
-        table = utils.get_table(self.engine, table_name)
-        self.assertIsInstance(table.c.deleted.type, Integer)
-
-    def test_change_deleted_column_type_to_id_type_string(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', String(255), primary_key=True),
-                      Column('deleted', Boolean))
-        table.create(self.engine)
-        utils.change_deleted_column_type_to_id_type(self.engine, table_name)
-
-        table = utils.get_table(self.engine, table_name)
-        self.assertIsInstance(table.c.deleted.type, String)
-
-    @db_test_base.backend_specific('sqlite')
-    def test_change_deleted_column_type_to_id_type_custom(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('foo', CustomType),
-                      Column('deleted', Boolean))
-        table.create(self.engine)
-
-        fooColumn = Column('foo', CustomType())
-        utils.change_deleted_column_type_to_id_type(self.engine, table_name,
-                                                    foo=fooColumn)
-
-        table = utils.get_table(self.engine, table_name)
-
-        self.assertIsInstance(table.c.deleted.type, Integer)
-
-    def test_change_deleted_column_type_to_boolean(self):
-        expected_types = {'mysql': mysql.TINYINT}
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('deleted', Integer))
-        table.create(self.engine)
-
-        utils.change_deleted_column_type_to_boolean(self.engine, table_name)
-
-        table = utils.get_table(self.engine, table_name)
-        self.assertIsInstance(table.c.deleted.type,
-                              expected_types.get(self.engine.name, Boolean))
-
-    def test_change_deleted_column_type_to_boolean_with_fc(self):
-        expected_types = {'mysql': mysql.TINYINT}
-        table_name_1 = 'abc'
-        table_name_2 = 'bcd'
-
-        table_1 = Table(table_name_1, self.meta,
-                        Column('id', Integer, primary_key=True),
-                        Column('deleted', Integer))
-        table_1.create(self.engine)
-
-        table_2 = Table(table_name_2, self.meta,
-                        Column('id', Integer, primary_key=True),
-                        Column('foreign_id', Integer,
-                               ForeignKey('%s.id' % table_name_1)),
-                        Column('deleted', Integer))
-        table_2.create(self.engine)
-
-        utils.change_deleted_column_type_to_boolean(self.engine, table_name_2)
-
-        table = utils.get_table(self.engine, table_name_2)
-        self.assertIsInstance(table.c.deleted.type,
-                              expected_types.get(self.engine.name, Boolean))
-
-    @db_test_base.backend_specific('sqlite')
-    def test_change_deleted_column_type_to_boolean_type_custom(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('foo', CustomType),
-                      Column('deleted', Integer))
-        table.create(self.engine)
-
-        fooColumn = Column('foo', CustomType())
-        utils.change_deleted_column_type_to_boolean(self.engine, table_name,
-                                                    foo=fooColumn)
-
-        table = utils.get_table(self.engine, table_name)
-        self.assertIsInstance(table.c.deleted.type, Boolean)
-
     def test_detect_boolean_deleted_constraint_detection(self):
         table_name = 'abc'
         table = Table(table_name, self.meta,
@@ -922,33 +798,6 @@ class TestMigrationUtils(db_test_base._DbTestCase):
             )
         )
 
-    @db_test_base.backend_specific('sqlite')
-    def test_change_deleted_column_type_sqlite_drops_check_constraint(self):
-        table_name = 'abc'
-        table = Table(table_name, self.meta,
-                      Column('id', Integer, primary_key=True),
-                      Column('deleted', Boolean))
-        table.create(self.engine)
-
-        utils._change_deleted_column_type_to_id_type_sqlite(self.engine,
-                                                            table_name)
-        table = Table(table_name, self.meta, autoload_with=self.engine)
-        # NOTE(I159): if the CHECK constraint has been dropped (expected
-        # behavior), any integer value can be inserted, otherwise only 1 or 0.
-        # NOTE(zzzeek): SQLAlchemy 1.2 Boolean type will disallow non 1/0
-        # value here, 1.1 also coerces to "1/0" so use raw SQL to test the
-        # constraint
-        with self.engine.connect() as conn:
-            conn.exec_driver_sql(
-                "INSERT INTO abc (deleted) VALUES (?)",
-                (10, ),
-            )
-
-            self.assertEqual(
-                10,
-                conn.scalar(sql.text("SELECT deleted FROM abc")),
-            )
-
     def test_get_foreign_key_constraint_name(self):
         table_1 = Table('table_name_1', self.meta,
                         Column('id', Integer, primary_key=True),
@@ -1020,7 +869,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
             normalize_fk_entries(existing_foreign_keys)
         )
 
-        with mock.patch("oslo_db.sqlalchemy.ndb.ndb_status",
+        with mock.patch("oslo_db.sqlalchemy.ndb._ndb_status",
                         mock.Mock(return_value=True)):
             with utils.suspend_fk_constraints_for_col_alter(
                     self.engine, 'a', 'id', referents=['b', 'c']):
@@ -1034,7 +883,7 @@ class TestMigrationUtils(db_test_base._DbTestCase):
 
         self.assertEqual(existing_foreign_keys, get_fk_entries())
 
-        with mock.patch("oslo_db.sqlalchemy.ndb.ndb_status",
+        with mock.patch("oslo_db.sqlalchemy.ndb._ndb_status",
                         mock.Mock(return_value=True)):
             with utils.suspend_fk_constraints_for_col_alter(
                     self.engine, 'b', 'archive_id', referents=['c']):
@@ -1652,7 +1501,7 @@ class TestDialectFunctionDispatcher(test_base.BaseTestCase):
 class TestGetInnoDBTables(db_test_base._MySQLOpportunisticTestCase):
 
     def test_all_tables_use_innodb(self):
-        with self.engine.connect() as conn:
+        with self.engine.connect() as conn, conn.begin():
             conn.execute(
                 sql.text(
                     "CREATE TABLE customers "
@@ -1660,21 +1509,23 @@ class TestGetInnoDBTables(db_test_base._MySQLOpportunisticTestCase):
         self.assertEqual([], utils.get_non_innodb_tables(self.engine))
 
     def test_all_tables_use_innodb_false(self):
-        with self.engine.connect() as conn:
+        with self.engine.connect() as conn, conn.begin():
             conn.execute(
-                sql.text("CREATE TABLE employee (i INT) ENGINE=MEMORY"))
+                sql.text("CREATE TABLE employee (i INT) ENGINE=MEMORY")
+            )
         self.assertEqual(['employee'],
                          utils.get_non_innodb_tables(self.engine))
 
     def test_skip_tables_use_default_value(self):
-        with self.engine.connect() as conn:
+        with self.engine.connect() as conn, conn.begin():
             conn.execute(
-                sql.text("CREATE TABLE migrate_version (i INT) ENGINE=MEMORY"))
+                sql.text("CREATE TABLE migrate_version (i INT) ENGINE=MEMORY")
+            )
         self.assertEqual([],
                          utils.get_non_innodb_tables(self.engine))
 
     def test_skip_tables_use_passed_value(self):
-        with self.engine.connect() as conn:
+        with self.engine.connect() as conn, conn.begin():
             conn.execute(
                 sql.text("CREATE TABLE some_table (i INT) ENGINE=MEMORY"))
         self.assertEqual([],
@@ -1682,7 +1533,7 @@ class TestGetInnoDBTables(db_test_base._MySQLOpportunisticTestCase):
                              self.engine, skip_tables=('some_table',)))
 
     def test_skip_tables_use_empty_list(self):
-        with self.engine.connect() as conn:
+        with self.engine.connect() as conn, conn.begin():
             conn.execute(
                 sql.text("CREATE TABLE some_table_3 (i INT) ENGINE=MEMORY"))
         self.assertEqual(['some_table_3'],
@@ -1690,7 +1541,7 @@ class TestGetInnoDBTables(db_test_base._MySQLOpportunisticTestCase):
                          self.engine, skip_tables=()))
 
     def test_skip_tables_use_several_values(self):
-        with self.engine.connect() as conn:
+        with self.engine.connect() as conn, conn.begin():
             conn.execute(
                 sql.text("CREATE TABLE some_table_1 (i INT) ENGINE=MEMORY"))
             conn.execute(
